@@ -9,6 +9,7 @@ from enum import Enum
 import numpy as np
 from scipy import integrate
 from scipy.stats import norm
+from scipy.stats import truncnorm
 import openquake.hazardlib.const as oqconst
 
 from esi_utils_rupture.quad_rupture import QuadRupture
@@ -232,7 +233,7 @@ class FFSimmer:
 
         gd = grid.getGeoDict()
         if gd.xmin > gd.xmax:
-            lons = np.linspace(gd.xmin, gd.xmax+360., gd.nx)
+            lons = np.linspace(gd.xmin, gd.xmax + 360.0, gd.nx)
         else:
             lons = np.linspace(gd.xmin, gd.xmax, gd.nx)
         glon, glat = np.meshgrid(
@@ -668,6 +669,7 @@ class RandomFiniteFault(object):
         aspect_ratio=-1,
         min_sz_depth=0,
         max_sz_depth=-1,
+        area_trunc=2,
         seed=None,
     ):
         """
@@ -720,6 +722,7 @@ class RandomFiniteFault(object):
             aspect_ratio,
             min_sz_depth,
             max_sz_depth,
+            area_trunc,
         )
 
     def initialize(
@@ -734,6 +737,7 @@ class RandomFiniteFault(object):
         aspect_ratio,
         min_sz_depth,
         max_sz_depth,
+        area_trunc,
     ):
         """
         Initialize the random arrays
@@ -751,11 +755,19 @@ class RandomFiniteFault(object):
         depth = hypo.z
         if depth > szdepth:
             szdepth = depth
-        depth = self.rng.normal(depth, 10.0, self.nsim)
+        # depth = self.rng.normal(depth, 10.0, self.nsim)
+        depth = truncnorm.rvs(
+            -2, 2, loc=depth, scale=10.0, size=self.nsim, random_state=self.rng
+        )
         depth[depth < min_sz_depth] = min_sz_depth
         depth[depth > szdepth] = szdepth
-        area = 10 ** self.rng.normal(
-            np.log10(area_mean[0]), area_std, self.nsim
+        area = 10 ** truncnorm.rvs(
+            -area_trunc,
+            area_trunc,
+            loc=np.log10(area_mean[0]),
+            scale=area_std,
+            size=self.nsim,
+            random_state=self.rng,
         )
         if min_dip is not None:
             mindip_deg = min_dip
@@ -805,9 +817,19 @@ class RandomFiniteFault(object):
         dx_min = dx_min_frac * length
         dx_max = dx_max_frac * length
         if dx_min_frac == 0 and dx_max_frac == 1:
-            frac = self.rng.normal(0.5, 0.23, self.nsim)
-            frac[frac < 0] = 0
-            frac[frac > 1] = 1
+            a_trunc = 0.0
+            b_trunc = 1.0
+            loc = 0.5
+            scale = 0.23
+            a, b = (a_trunc - loc) / scale, (b_trunc - loc) / scale
+            frac = truncnorm.rvs(
+                a,
+                b,
+                loc=loc,
+                scale=scale,
+                size=self.nsim,
+                random_state=self.rng,
+            )
         else:
             frac = self.rng.uniform(size=self.nsim)
         dx = dx_min + frac * (dx_max - dx_min)
@@ -858,6 +880,8 @@ class RandomFiniteFault(object):
         x = np.linspace(0, 1, 1000)
         y = weibull(A, B, x)
         cdf = integrate.cumulative_trapezoid(y, x, initial=x[0])
+        nrm = cdf[-1] - cdf[0]
+        cdf = cdf / nrm
         icdf = np.interp(x, cdf, x)
         uniform_samples = self.rng.uniform(size=nsamp)
         rnd_array = np.interp(uniform_samples, x, icdf)
